##
##  xpdf.spec -- OpenPKG RPM Package Specification
##  Copyright (c) 2000-2024 OpenPKG Project <http://openpkg.org/>
##
##  Permission to use, copy, modify, and distribute this software for
##  any purpose with or without fee is hereby granted, provided that
##  the above copyright notice and this permission notice appear in all
##  copies.
##
##  THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
##  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
##  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
##  IN NO EVENT SHALL THE AUTHORS AND COPYRIGHT HOLDERS AND THEIR
##  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
##  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
##  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
##  USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
##  ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
##  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
##  OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
##  SUCH DAMAGE.
##

#   package version
%define       V_base       4.05
%define       V_patchlevel 0

#   package information
Name:         xpdf
Summary:      Portable Document Format (PDF) Viewer
URL:          http://www.xpdfreader.com/
Vendor:       FooLabs
Packager:     OpenPKG Project
Distribution: OpenPKG Community
Class:        EVAL
Group:        Postscript
License:      GPL
Version:      %{V_base}pl%{V_patchlevel}
Release:      20240211

#   list of sources
Source0:      https://dl.xpdfreader.com/xpdf-%{V_base}.tar.gz

#   build information
BuildPreReq:  OpenPKG, openpkg >= 20160101, gcc, gcc::with_cxx = yes
PreReq:       OpenPKG, openpkg >= 20160101
BuildPreReq:  freetype, png
PreReq:       freetype, png

%description
    Xpdf is an open source viewer for Portable Document Format (PDF)
    files, sometimes also called 'Acrobat' files, from the name of
    Adobe's PDF software. The Xpdf project also includes a PDF text
    extractor, PDF-to-PostScript converter, and various other utilities.

%track
    prog xpdf = {
        version   = %{V_base}
        url       = http://www.xpdfreader.com/download.html
        regex     = xpdf-(__VER__)\.tar\.gz
    }
    prog xpdf:patchlevel = {
        version   = %{V_patchlevel}
        url       = http://www.xpdfreader.com/download.html
        regex     = xpdf-%{V_base}pl(__VER__)\.patch
    }

%prep
    %setup -q -n xpdf-%{V_base}

%build
    mkdir build
    cd build
    cmake \
        -DCMAKE_BUILD_TYPE="Release" \
        -DCMAKE_INSTALL_PREFIX="%{l_prefix}" \
        -DCMAKE_C_COMPILER="%{l_cc}" \
        -DCMAKE_C_FLAGS="%{l_cflags} %{l_cppflags}" \
        -DCMAKE_EXE_LINKER_FLAGS="%{l_ldflags}" \
        -DCMAKE_CXX_COMPILER="%{l_cxx}" \
        -DCMAKE_CXX_FLAGS="%{l_cxxflags} %{l_cppflags} -Wno-deprecated" \
        -DSYSTEM_XPDFRC="%{l_prefix}/etc/xpdf/xpdfrc" \
        -DA4_PAPER=ON \
        ..
    %{l_make} %{l_mflags}

%install
    %{l_shtool} mkdir -f -p -m 755 \
        $RPM_BUILD_ROOT%{l_prefix}/bin \
        $RPM_BUILD_ROOT%{l_prefix}/etc/xpdf \
        $RPM_BUILD_ROOT%{l_prefix}/man/man1 \
        $RPM_BUILD_ROOT%{l_prefix}/man/man5
    %{l_shtool} install -c -s -m 755 \
        build/xpdf/pdfdetach build/xpdf/pdffonts build/xpdf/pdfimages build/xpdf/pdfinfo \
        build/xpdf/pdftohtml build/xpdf/pdftopng build/xpdf/pdftoppm build/xpdf/pdftops \
        build/xpdf/pdftotext \
        $RPM_BUILD_ROOT%{l_prefix}/bin/
    %{l_shtool} install -c -m 755 \
        -e 's;/usr/local/share/ghostscript/fonts;%{l_prefix}/share/ghostscript/fonts;' \
        doc/sample-xpdfrc \
        $RPM_BUILD_ROOT%{l_prefix}/etc/xpdf/xpdfrc
    %{l_shtool} install -c -m 644 \
        doc/*.1 $RPM_BUILD_ROOT%{l_prefix}/man/man1/
    %{l_shtool} install -c -m 644 \
        doc/*.5 $RPM_BUILD_ROOT%{l_prefix}/man/man5/
    %{l_rpmtool} files -v -ofiles -r$RPM_BUILD_ROOT \
        %{l_files_std} \
        '%config %{l_prefix}/etc/xpdf/*'

%files -f files

%clean

